@@ -73,7 +73,11 @@ django.jQuery(function ($) {
 
   // Add basic structure. There is always at least one inline group if
   // we even have any plugins.
-  $(".inline-group:first").before(
+  let $anchor = $(".inline-group:first");
+  if (ContentEditor.plugins.length) {
+    $anchor = $("#" + ContentEditor.plugins[0].prefix + "-group");
+  }
+  $anchor.before(
     '<div class="tabs regions">' +
       '<label class="toggle"><input type="checkbox" /> ' +
       ContentEditor.messages.toggle +
@@ -272,14 +276,12 @@ django.jQuery(function ($) {
 
     if (regions.length < 2) return;
 
-    const controls = document.createElement("div"),
-      select = buildDropdown(regions),
+    const select = buildDropdown(regions),
       regionInput = $inline.find(".field-region input");
 
+    select.className = "inline_move_to_region";
     select.value = regionInput.val();
-    controls.className = "inline-controls";
-    controls.appendChild(select);
-    $inline.append(controls);
+    $inline.find("> h3").append(select);
 
     select.addEventListener("change", function () {
       $inline.attr("data-region", select.value);
@@ -455,7 +457,11 @@ django.jQuery(function ($) {
         .filter('[data-region="' + ContentEditor.currentRegion + '"]')
         .addClass("active");
       hideInlinesFromOtherRegions();
-      window.location.hash = "tab_" + ContentEditor.currentRegion;
+      window.history.replaceState(
+        null,
+        "",
+        "#tab_" + ContentEditor.currentRegion
+      );
 
       // Make sure only allowed plugins are in select
       hideNotAllowedDropdown();
@@ -478,7 +484,7 @@ django.jQuery(function ($) {
 
     const collapseAllInput = tabContainer.find(".toggle input");
     collapseAllInput.on("change", function () {
-      $(".order-machine .inline-related").toggleClass(
+      $(".order-machine .inline-related:not(.empty-form)").toggleClass(
         "collapsed",
         this.checked
       );
@@ -504,16 +510,35 @@ django.jQuery(function ($) {
         "for-deletion",
         this.checked
       );
+      this.blur();
     }
   );
 
-  orderMachine.on("click", "h3", function toggleCollapsed(e) {
-    if (e.target.tagName === "H3") {
+  orderMachine.on("click", ".inline-related>h3", function toggleCollapsed(e) {
+    if (
+      !e.target.closest(".delete") &&
+      !e.target.closest(".inline_move_to_region")
+    ) {
       e.preventDefault();
       this.closest(".inline-related").classList.toggle("collapsed");
     }
   });
 
+  // Since we pulled out the fieldsets from their containing module
+  // we have to reimplement the Show/Hide toggle for order machine items.
+  orderMachine.on("click", ".collapse-toggle", function toggleCollapsed(e) {
+    // This only reaches us if it hasn't been handled by Django's collapse.js
+    e.preventDefault();
+    const fieldset = this.closest("fieldset");
+    if (fieldset.classList.contains("collapsed")) {
+      e.target.textContent = window.gettext("Hide");
+      fieldset.classList.remove("collapsed");
+    } else {
+      e.target.textContent = window.gettext("Show");
+      fieldset.classList.add("collapsed");
+    }
+  });
+
   // Try to keep the current region tab (location hash).
   $("form").submit(function () {
     const form = $(this);
